/********************************************************************
 *            callbacks.c
 *
 *  Sat Jul 29 14:14:25 2006
 *  Copyright  2006  Neil Williams
 *  linux@codehelp.co.uk
 ********************************************************************/
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include "dvarchive.h"
#include "callbacks.h"
#include "interface.h"
#include "support.h"

void
on_ok_clicked (GtkButton * button, gpointer data)
{
	dv_archive_free ();
	gtk_main_quit ();
}

void
on_open_deb (GtkMenuItem * menuitem, gpointer user_data)
{
	GtkWidget *chooser;

	chooser = gtk_file_chooser_dialog_new
		(_("Choose the Debian package file to view"),
		NULL, GTK_FILE_CHOOSER_ACTION_OPEN,
		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser),
		"/var/cache/apt/archives");
	if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_ACCEPT)
	{
		gchar *filename;

		dv_archive_free ();
		filename = gtk_file_chooser_get_filename
			(GTK_FILE_CHOOSER (chooser));
		open_deb (filename, GTK_WIDGET (menuitem));
		g_free (filename);
	}
	gtk_widget_destroy (chooser);
}


void
on_quit_activate (GtkMenuItem * menuitem, gpointer user_data)
{
	dv_archive_free ();
	gtk_main_quit ();
}

void
on_about_activate (GtkMenuItem * menuitem, gpointer user_data)
{
	GtkAboutDialog *ab;

	ab = GTK_ABOUT_DIALOG (create_aboutdialog ());
	gtk_widget_show (GTK_WIDGET (ab));
}

void
on_treeview_row_activated (GtkTreeView * treeview,
	GtkTreePath * path, GtkTreeViewColumn * column, 
	gpointer user_data)
{
	const gchar *file;
	gchar * text;
	GValue *value;
	GtkTreeIter iter;
	GtkTreeModel *model;

	value = g_new0 (GValue, 1);
	model = gtk_tree_view_get_model (treeview);
	gtk_tree_model_get_iter (model, &iter, path);
	gtk_tree_model_get_value (model, &iter, LOCATION_COLUMN, value);
	file = g_value_get_string (value);
	if (!file)
		return;
	text = dv_get_data_content (file);
	if (text)
	{
		GtkWidget *display_area;
		GtkTextBuffer *buffer;

		display_area = lookup_widget 
			(GTK_WIDGET(treeview), "display");
		buffer = gtk_text_view_get_buffer (
			GTK_TEXT_VIEW (display_area));
		gtk_text_buffer_set_text (buffer, text, -1);
		gtk_text_view_set_buffer (
			GTK_TEXT_VIEW(display_area), buffer);
	}
	else
	{
		text = dv_get_control_content (file);
		if (text)
		{
			GtkWidget *display_area;
			GtkTextBuffer *buffer;
			display_area = lookup_widget 
				(GTK_WIDGET(treeview), "display");
			buffer = gtk_text_view_get_buffer (
				GTK_TEXT_VIEW (display_area));
			gtk_text_buffer_set_text (buffer, text, -1);
			gtk_text_view_set_buffer (
				GTK_TEXT_VIEW(display_area), buffer);
		}
	}
	g_free (value);
}

void
on_dpkg_view_window_activate_default (GtkWidget * widget,
	gpointer user_data)
{
	dv_archive_preload (widget);
}

gboolean
on_dpkg_view_window_destroy_event (GtkWidget * widget,
	GdkEvent * event, gpointer user_data)
{
	dv_archive_free ();
	gtk_main_quit ();
	return FALSE;
}

void
on_dpkg_view_window_destroy (GtkObject * object, gpointer user_data)
{
	dv_archive_free ();
	gtk_main_quit ();
}
